import Page from "@/components/Page";
import {
  PrivateIndividualsShareCapitalUnlimitedCompany,
  PrivateSharesCorporation,
  PublicShareCapitalUnlimitedCompany,
  PublicSharesCorporation,
} from "@/utils/company";
import { ProCard, ProDescriptions } from "@ant-design/pro-components";
import {
  Badge,
  Button,
  Card,
  Col,
  Descriptions,
  Image,
  Row,
  Space,
} from "antd";
import React, { useEffect, useState } from "react";
import { useSearchParams } from "react-router-dom";
import UploadFile from "./component/UploadFile";
import PreviewModal from "./component/PreviewModal";
import {
  getTaCompanyRealName,
  getTaCompanyRealNameId,
} from "@/services/companyreal";
import { DownloadOutlined } from "@ant-design/icons";
export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  const [companyList, setCompanyList] = useState({});
  const requestApi = async () => {
    const res = await getTaCompanyRealNameId(id);
    const data = {
      success: true,
      data: {
        ...res,
        ...(res.taCompanyInfo || {}),
      },
    };
    console.log(data);
    return data;
  };

  const classification = (value) => {
    const str = value;
    const fileExtension = str.substring(str.lastIndexOf(".") + 1);

    if (fileExtension == "rar" || fileExtension == "zip") {
      return (
        <div>
          <div>{value}</div>
          <Button
            href={value}
            type="primary"
            shape="round"
            icon={<DownloadOutlined />}
            size="middle"
          />
        </div>
      );
    } else if (
      fileExtension == "jpg" ||
      fileExtension == "jpeg" ||
      fileExtension == "png"
    ) {
      return <img src={value} alt="" height="100" width="100" />;
    } else if (fileExtension == "xlsx" || fileExtension == "xls") {
      <div>
        <div>{value}</div>
        <Button
          href={value}
          type="primary"
          shape="round"
          icon={<DownloadOutlined />}
          size="middle"
        />
      </div>;
    } else if (fileExtension == "pdf") {
      <iframe src={value} height="100%" width="100%"></iframe>;
    }
  };

  const columns = [
    {
      title: "企业注册地",
      dataIndex: "registrationLocation",
    },
    {
      title: "企业中文名",
      dataIndex: "companyNameCn",
    },
    {
      title: "企业英文名",
      dataIndex: "companyNameEn",
    },
    {
      title: "是否为上市企业",
      dataIndex: "isListedCompany",
      valueType: "select",
      valueEnum: {
        0: { text: "否" },
        1: { text: "是" },
      },
    },

    {
      title: "企业类型",
      dataIndex: "companyType",
      valueType: "select",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.companyType;
      // },
      valueEnum: {
        1: {
          text: PrivateSharesCorporation,
        },
        2: {
          text: PublicSharesCorporation,
        },
        3: {
          text: PublicShareCapitalUnlimitedCompany,
        },
        4: {
          text: PrivateIndividualsShareCapitalUnlimitedCompany,
        },
      },
    },
    {
      title: "商业登记号",
      dataIndex: "businessRegistrationNum",
    },
    {
      title: "公司注册证书",
      dataIndex: "certificateIncorporation",
      render: (_, r) => {
        return classification(r?.certificateIncorporation);
      },
    },
    {
      title: "公司商业登记证",
      dataIndex: "companyBusinessRegistration",
      render: (_, r) => {
        return classification(r?.companyBusinessRegistration);
      },
    },
    {
      title: "nnc1/最新nar1",
      // valueType: "image",
      dataIndex: "nnc1Nar1",
      render: (_, r) => {
        return classification(r?.nnc1Nar1);
      },
    },
    {
      title: "其他附件",
      dataIndex: "otherAnnex",
      render: (_, r) => {
        return classification(r?.otherAnnex);
      },
    },
    {
      title: "注册-国家",
      dataIndex: "registerCountry",
    },
    {
      title: "注册-省/地区",
      dataIndex: "registerProvinceRegion",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.registerProvinceRegion;
      // },
    },
    {
      title: "注册-市",
      dataIndex: "registerCity",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.registerCity;
      // },
    },
    {
      title: "注册-具体地址",
      dataIndex: "registerSpecificAddress",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.registerSpecificAddress;
      // },
    },
    {
      title: "注册-邮政编码",
      dataIndex: "registerPostalCode",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.registerPostalCode;
      // },
    },
    {
      title: "实际-国家",
      dataIndex: "realityCountry",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.realityCountry;
      // },
    },
    {
      title: "实际-省/地区",
      dataIndex: "realityProvinceRegion",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.realityProvinceRegion;
      // },
    },
    {
      title: "实际-市",
      dataIndex: "realityCity",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.realityCity;
      // },
    },
    {
      title: "实际-具体地址",
      dataIndex: "realitySpecificAddress",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.realitySpecificAddress;
      // },
    },
    {
      title: "实际-邮政编码",
      dataIndex: "realityPostalCode",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.realityPostalCode;
      // },
    },
    {
      title: "雇员人数",
      dataIndex: "numEmployees",
      valueType: "select",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.numEmployees;
      // },
      valueEnum: {
        1: { text: "员工人数超过200人" },
        2: { text: "员工人数50-200人" },
        3: { text: "员工人数少于50人" },
      },
    },
    {
      title: "经营场所类型",
      dataIndex: "businessPremisesType",
      valueType: "select",
      // render: (_, r) => {
      //   return r.taCompanyInfo?.businessPremisesType;
      // },
      valueEnum: {
        1: { text: "自有办公场所" },
        2: { text: "较大租用办公场所 (大于500平方)" },
        3: { text: "较小租用办公场所 (小于500平方)" },
        4: { text: "无固定办公场所" },
      },
    },
    {
      title: "受益人",
      dataIndex: "taCompanyBeneficiaryInfoList",
      render: (_, r) => {
        const data = (r.taCompanyBeneficiaryInfoList || []).map(
          (x) => x.beneficiaryName
        );
        // console.log(data);
        return data.join(" ，");
      },
    },
    {
      title: "董事",
      dataIndex: "taCompanyLegalInfoList",
      render: (_, r) => {
        const data = (r.taCompanyLegalInfoList || []).map(
          (x) => x.directorNameCn
        );
        return data.join(" ，");
      },
    },
  ];
  const [isModalOpen, setIsModalOpen] = React.useState(false);
  const [content, setContent] = React.useState();

  const onOpen = () => {
    setIsModalOpen(true);
  };
  const onClose = () => {
    setIsModalOpen(false);
  };

  return (
    <Page>
      <Row>
        <ProCard gutter={20}>
          <ProDescriptions
            layout="vertical"
            bordered
            title="公司基本信息"
            request={requestApi}
            columns={columns}
          ></ProDescriptions>
        </ProCard>
      </Row>
      {/* <PreviewModal
        isModalOpen={isModalOpen}
        onClose={onClose}
        versionInfo={content}
      /> */}
    </Page>
  );
};
