import React from "react";
import { UploadOutlined } from "@ant-design/icons";
import { Button } from "antd";
import Upload from "@/components/Upload/Upload";

const getFileInfo = (x) => ({
  uid: x,
  name: x?.split("/")?.at(-1)?.replace(/^\d+-/, ""),
  status: "done",
  thumbUrl: x,
  url: x,
});

export default (props) => {
  const { value, onChange, onPreview, versionInfo, accept = ".ppt,.pptx,.pdf" } = props;

  const [loading, setLoading] = React.useState(false);

  const [fileList, setFileList] = React.useState([]);


  const handleChange = (info) => {
    const newFileList = [...info.fileList];

    if (info.file.status === "uploading") {
      setLoading(true);
    } else if (info.file.status === "error") {
      setLoading(false);
    } else if (info.file.status === "done") {
      setLoading(false);
      const { url, fileType } = info.file.response;
      if (onChange) {
        onChange(url, fileType);
      }
    }

    setFileList(newFileList);
  };

  const handlePreview = (e) => {
    e.preventDefault();
    e.stopPropagation();
    onPreview();
  }

  React.useEffect(() => {
    if (!value) {
      setFileList([]);
    } else {
      setFileList([getFileInfo(value)]);
    }
  }, [value]);

  // console.log('versionInfo', versionInfo)

  return (
    <>
      <Upload
        accept={accept}
        fileList={fileList}
        onChange={handleChange}
      >
        <Button loading={loading} icon={<UploadOutlined />}>
          点击上传文件
        </Button>
        {
          versionInfo ? <Button type="link" onClick={handlePreview} >预览</Button> : null
        }
      </Upload>
    </>
  );
};
