import {
  UserOutlined,
  SolutionOutlined,
  FileTextOutlined,
} from "@ant-design/icons";
import { Outlet, Navigate } from "react-router-dom";
import AuthLayout from "@/layouts/AuthLayout";
import Login from "@/pages/login";
import Page404 from "@/pages/404";
import FxUser from "@/pages/fxuser";
import FxUserEdit from "@/pages/fxuser/Edit";
import Tenant from "@/pages/tenant";
import TenantEdit from "@/pages/tenant/Edit";
import Company from "@/pages/company";
import CompanyEdit from "@/pages/company/Edit";

/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */

export const authRoutes = [
  {
    // index: true,
    element: <Navigate to="/fxuser" replace={true} />,
  },
  {
    path: "fxuser",
    element: <FxUser />,
    meta: {
      title: "用户管理",
      icon: <SolutionOutlined />,
    },
  },
  {
    path: "fxuser/edit",
    element: <FxUserEdit />,
    meta: {
      title: "用户维护",
      hideInMenu: true,
    },
  },
  // {
  //   path: "tenant",
  //   element: <Tenant />,
  //   meta: {
  //     title: "租户管理",
  //     icon: <UserOutlined />,
  //   },
  // },
  // {
  //   path: "tenant/edit",
  //   element: <TenantEdit />,
  //   meta: {
  //     title: "租户维护",
  //     hideInMenu: true,
  //   },
  // },
  {
    path: "company",
    element: <Company />,
    meta: {
      title: "公司列表",
      icon: <UserOutlined />,
    },
  },
  {
    path: "company/edit",
    element: <CompanyEdit />,
    meta: {
      title: "公司详情",
      hideInMenu: true,
    },
  },
];

export const defaultRoutes = [
  {
    path: "/",
    element: <AuthLayout />,
    children: [
      {
        path: "*",
        element: <Page404 />,
      },
    ],
  },
  {
    path: "/login",
    element: <Login />,
  },
  {
    path: "*",
    element: <Page404 />,
  },
];

export function mergeAuthRoutes (r1, r2) {
  const r = r1.slice();
  const children = r1[0].children.slice();
  r[0].children = children.concat(r2);
  return r;
}

// 全部路由
export const routes = mergeAuthRoutes(defaultRoutes, authRoutes);
function getPath (parent = "/", current = "") {
  if (current.indexOf("/") === 0 || current.indexOf("http") === 0)
    return current;
  return `${parent}/${current}`.replace(/\/\//g, "/");
}

// 路由数组, 一维数组
export const routeArr = (() => {
  const flatten = (routes, parentPath = "/") => {
    return routes.reduce((acc, route) => {
      const path = getPath(parentPath, route.path);
      const children = route.children ? flatten(route.children, path) : [];

      return acc.concat([{ ...route, path }].concat(children));
    }, []);
  };

  return flatten(routes);
})();
